# coding: utf-8

"""
    Catalog Sampling API

    <p>The Catalog Sampling API offers functionality related to the Collibra Data Catalog application.<br/> It is mainly focused on facilitating the ingestion of information into Data Catalog.<br/> The API enables you to more easily connect Data Catalog to sources that are not necessarily natively supported in the product.</p>  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import collibra_catalog_sampling
from collibra_catalog_sampling.api.samples_api import SamplesApi  # noqa: E501
from collibra_catalog_sampling.rest import ApiException


class TestSamplesApi(unittest.TestCase):
    """SamplesApi unit test stubs"""

    def setUp(self):
        self.api = SamplesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_read_samples(self):
        """Test case for read_samples

        Read sample data from the Collibra cloud repository or Edge cache  # noqa: E501
        """
        pass

    def test_request_samples(self):
        """Test case for request_samples

        Create a request to collect and cache sample data for an Edge data source  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
