# coding: utf-8

"""
    Catalog Sampling API

    <p>The Catalog Sampling API offers functionality related to the Collibra Data Catalog application.<br/> It is mainly focused on facilitating the ingestion of information into Data Catalog.<br/> The API enables you to more easily connect Data Catalog to sources that are not necessarily natively supported in the product.</p>  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import collibra_catalog_sampling
from collibra_catalog_sampling.models.standard_error_response import StandardErrorResponse  # noqa: E501
from collibra_catalog_sampling.rest import ApiException


class TestStandardErrorResponse(unittest.TestCase):
    """StandardErrorResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testStandardErrorResponse(self):
        """Test StandardErrorResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = collibra_catalog_sampling.models.standard_error_response.StandardErrorResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
