# coding: utf-8

"""
    Catalog Sampling API

    <p>The Catalog Sampling API offers functionality related to the Collibra Data Catalog application.<br/> It is mainly focused on facilitating the ingestion of information into Data Catalog.<br/> The API enables you to more easily connect Data Catalog to sources that are not necessarily natively supported in the product.</p>  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class RequestSamplesResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'new_job': 'bool',
        'job': 'Job'
    }

    attribute_map = {
        'new_job': 'newJob',
        'job': 'job'
    }

    def __init__(self, new_job=None, job=None):  # noqa: E501
        """RequestSamplesResponse - a model defined in Swagger"""  # noqa: E501
        self._new_job = None
        self._job = None
        self.discriminator = None
        if new_job is not None:
            self.new_job = new_job
        if job is not None:
            self.job = job

    @property
    def new_job(self):
        """Gets the new_job of this RequestSamplesResponse.  # noqa: E501

        Whether this is a newly created job or one that is in progress.  # noqa: E501

        :return: The new_job of this RequestSamplesResponse.  # noqa: E501
        :rtype: bool
        """
        return self._new_job

    @new_job.setter
    def new_job(self, new_job):
        """Sets the new_job of this RequestSamplesResponse.

        Whether this is a newly created job or one that is in progress.  # noqa: E501

        :param new_job: The new_job of this RequestSamplesResponse.  # noqa: E501
        :type: bool
        """

        self._new_job = new_job

    @property
    def job(self):
        """Gets the job of this RequestSamplesResponse.  # noqa: E501


        :return: The job of this RequestSamplesResponse.  # noqa: E501
        :rtype: Job
        """
        return self._job

    @job.setter
    def job(self, job):
        """Sets the job of this RequestSamplesResponse.


        :param job: The job of this RequestSamplesResponse.  # noqa: E501
        :type: Job
        """

        self._job = job

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RequestSamplesResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RequestSamplesResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
